﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using System;
using System.Linq;
using System.Collections.Generic;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using SDKTemplateCS;
using NotificationsExtensions.BadgeContent;
using Windows.UI.Notifications;

namespace TilesCS
{
    public sealed partial class ScenarioInput4 : Page
    {
        MainPage rootPage = null;
        TextBlock output = null;

        public ScenarioInput4()
        {
            InitializeComponent();
            NumberOrGlyph.SelectedIndex = 0;
            GlyphList.SelectedIndex = 0;          
        }

        #region Template-Related Code - Do not remove
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Get a pointer to our main page
            rootPage = e.Parameter as MainPage;

            // We want to be notified with the OutputFrame is loaded so we can get to the content.
            rootPage.OutputFrameLoaded += new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            rootPage.OutputFrameLoaded -= new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        void rootPage_OutputFrameLoaded(object sender, object e)
        {
            Page outputFrame = (Page)rootPage.OutputFrame.Content;
            output = outputFrame.FindName("Output") as TextBlock;
        }

        #endregion

        #region Scenario-Template Code
        void NumberOrGlyph_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (NumberOrGlyph.SelectedIndex == 0)
            {
                NumberPanel.Visibility = Visibility.Visible;
                GlyphPanel.Visibility = Visibility.Collapsed;
            }
            else
            {
                NumberPanel.Visibility = Visibility.Collapsed;
                GlyphPanel.Visibility = Visibility.Visible;
            }
        }

        void UpdateBadge_Click(object sender, RoutedEventArgs e)
        {
            if (NumberOrGlyph.SelectedIndex == 0)
            {
                int number;
                if (Int32.TryParse(NumberInput.Text, out number))
                {
                    UpdateBadgeWithNumber(number);
                }
                else
                {
                    output.Text = "Please enter a valid number!";
                }
            }
            else
            {
                UpdateBadgeWithGlyph(GlyphList.SelectedIndex);
            }
        }
        #endregion

        void ClearBadge_Click(object sender, RoutedEventArgs e)
        {
            BadgeUpdateManager.CreateBadgeUpdaterForApplication().Clear();
            output.Text = "Badge cleared";
        }

        void UpdateBadgeWithNumber(int number)
        {
            BadgeNumericNotificationContent badgeContent = new BadgeNumericNotificationContent((uint)number);

            // send the notification to the app's application tile
            BadgeUpdateManager.CreateBadgeUpdaterForApplication().Update(badgeContent.CreateNotification());

            output.Text = badgeContent.GetContent();
        }

        void UpdateBadgeWithGlyph(int index)
        {
            BadgeGlyphNotificationContent badgeContent = new BadgeGlyphNotificationContent((GlyphValue)index);

            // send the notification to the app's application tile
            BadgeUpdateManager.CreateBadgeUpdaterForApplication().Update(badgeContent.CreateNotification());

            output.Text = badgeContent.GetContent();
        }
    }
}
