﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using System;
using System.Linq;
using System.Collections.Generic;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using SDKTemplateCS;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Data.Xml.Dom;
using Windows.UI.Notifications;
using Windows.UI.Xaml.Media.Imaging;

namespace TilesCS
{
    public sealed partial class ScenarioInput5 : Page
    {
        MainPage rootPage = null;
        TextBlock output = null;

        public ScenarioInput5()
        {
            InitializeComponent();
            Branding.SelectedIndex = 0;
            TemplateList.SelectedIndex = 0;
        }

        #region Template-Related Code - Do not remove
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Get a pointer to our main page
            rootPage = e.Parameter as MainPage;

            // We want to be notified with the OutputFrame is loaded so we can get to the content.
            rootPage.OutputFrameLoaded += new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            rootPage.OutputFrameLoaded -= new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        void rootPage_OutputFrameLoaded(object sender, object e)
        {
            Page outputFrame = (Page)rootPage.OutputFrame.Content;
            output = outputFrame.FindName("Output") as TextBlock;
        }
        #endregion

        #region  Scenario-Template Code
        async void ViewImages_Click(object sender, RoutedEventArgs e)
        {
            if (!AvailableImages.Text.Equals(String.Empty))
            {
                AvailableImages.Text = String.Empty;
                ViewImages.Content = "View local images";
            }
            else
            {
                string output = "ms-appx:///images/bluewide.png \n ms-appx:///images/redWide.png \n ms-appx:///images/graySquare.png \n";
                IReadOnlyList<StorageFile> files = await Windows.Storage.ApplicationData.Current.LocalFolder.GetFilesAsync();
                foreach (StorageFile file in files)
                {
                    if (file.FileType.Equals(".png") || file.FileType.Equals(".jpg") || file.FileType.Equals(".jpeg"))
                    {
                        output += "ms-appdata:///local/" + file.Name + " \n";
                    }
                }
                ViewImages.Content = "Hide local images";
                AvailableImages.Text = output;
            }
        }

        async void CopyImages_Click(object sender, RoutedEventArgs e)
        {
            FileOpenPicker picker = new Windows.Storage.Pickers.FileOpenPicker();
            picker.ViewMode = PickerViewMode.Thumbnail;
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.FileTypeFilter.Add(".jpg");
            picker.FileTypeFilter.Add(".jpeg");
            picker.FileTypeFilter.Add(".png");
            picker.CommitButtonText = "Copy";
            IReadOnlyList<StorageFile> files = await picker.PickMultipleFilesAsync();
            output.Text = "Image(s) copied to application data local storage: \n";
            foreach (StorageFile file in files)
            {
                StorageFile copyFile = await file.CopyAsync(Windows.Storage.ApplicationData.Current.LocalFolder, file.Name);
                output.Text += copyFile.Path + "\n ";
            }
        }

        private void TemplateList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ComboBoxItem item = TemplateList.SelectedItem as ComboBoxItem;
            string templateName = (item != null) ? item.Name : "TileSquareImage";
            XmlDocument tileXml = TileUpdateManager.GetTemplateContent((TileTemplateType)TemplateList.SelectedIndex);

            XmlNodeList tileTextAttributes = tileXml.GetElementsByTagName("text");
            for (int i = 0; i < TextInputs.Children.Count; i++)
            {
                if (i < tileTextAttributes.Length)
                {
                    TextInputs.Children[i].Visibility = Windows.UI.Xaml.Visibility.Visible;
                }
                else
                {
                    TextInputs.Children[i].Visibility = Windows.UI.Xaml.Visibility.Collapsed;
                }
            }

            XmlNodeList tileImageAttributes = tileXml.GetElementsByTagName("image");
            for (int i = 0; i < ImageInputs.Children.Count; i++)
            {
                if (i < tileImageAttributes.Length)
                {
                    ImageInputs.Children[i].Visibility = Windows.UI.Xaml.Visibility.Visible;
                }
                else
                {
                    ImageInputs.Children[i].Visibility = Windows.UI.Xaml.Visibility.Collapsed;
                }
            }

            Preview.Source = new BitmapImage(new Uri(Preview.BaseUri, "Images/tiles/" + templateName + ".png"));
        }
        #endregion

        void ClearTile_Click(object sender, RoutedEventArgs e)
        {
            TileUpdateManager.CreateTileUpdaterForApplication().Clear();
            output.Text = "Tile cleared";
        }

        void UpdateTileNotification_Click(object sender, RoutedEventArgs e)
        {
            ComboBoxItem item = (ComboBoxItem)(Branding.SelectedItem);
            string branding = (item.Name.Equals("BrandName")) ? "Name" : item.Name;

            UpdateTile((TileTemplateType)TemplateList.SelectedIndex, branding);
        }

        void UpdateTile(TileTemplateType templateType, string branding)
        {
            // This example uses the GetTemplateContent method to get the notification as xml instead of NotificationExtensions            

            XmlDocument tileXml = TileUpdateManager.GetTemplateContent(templateType);
            #region input handling

            XmlNodeList textElements = tileXml.GetElementsByTagName("text");
            for (int i = 0; i < textElements.Length; i++)
            {
                string tileText = String.Empty;
                StackPanel panel = TextInputs.Children[i] as StackPanel;
                if (panel != null)
                {
                    TextBox box = panel.Children[1] as TextBox;
                    if (box != null)
                    {
                        tileText = box.Text;
                        if (tileText.Equals(""))
                        {
                            tileText = "Text field " + i;
                        }
                    }
                }
                textElements.Item((uint)i).AppendChild(tileXml.CreateTextNode(tileText));
            }

            XmlNodeList imageElements = tileXml.GetElementsByTagName("image");
            for (int i = 0; i < imageElements.Length; i++)
            {
                XmlElement imageElement = (XmlElement)imageElements.Item((uint)i);
                string imageSource = String.Empty;
                StackPanel panel = ImageInputs.Children[i] as StackPanel;
                if (panel != null)
                {
                    TextBox box = panel.Children[1] as TextBox;
                    if (box != null)
                    {
                        imageSource = box.Text;
                        if (imageSource.Equals(String.Empty))
                        {
                            imageSource = "ms-appx:///images/redWide.png";
                        }
                    }
                }
                imageElement.SetAttribute("src", imageSource);
            }
            #endregion

            // Set branding, the logo and display name are declared in the manifest
            // defaults to logo if omitted
            XmlElement bindingElement = (XmlElement)tileXml.GetElementsByTagName("binding").Item(0);
            bindingElement.SetAttribute("branding", branding);

            string lang = Lang.Text; // this needs to be a BCP47 tag
            if (!String.IsNullOrEmpty(lang))
            {
                // specify the language of the text in the notification 
                // this ensure the correct font is used to render the text
                XmlElement visualElement = (XmlElement)tileXml.GetElementsByTagName("visual").Item(0);
                visualElement.SetAttribute("lang", lang);
            }

            TileNotification tile = new TileNotification(tileXml);
            TileUpdateManager.CreateTileUpdaterForApplication().Update(tile);

            output.Text = tileXml.GetXml();
        }
    }
}
