﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using System;
using System.Linq;
using System.Collections.Generic;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using SDKTemplateCS;
using System.Threading.Tasks;
using Windows.Storage.Pickers;
using Windows.Storage;
using NotificationsExtensions.TileContent;
using Windows.UI.Notifications;

namespace TilesCS
{
    public sealed partial class ScenarioInput8 : Page
    {
        MainPage rootPage = null;
        TextBlock output = null;
        string imageRelativePath = String.Empty; //used for copying an image to localstorage

        public ScenarioInput8()
        {
            InitializeComponent();
            ProtocolList.SelectedIndex = 0;
        }

        #region Template-Related Code - Do not remove
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Get a pointer to our main page
            rootPage = e.Parameter as MainPage;

            // We want to be notified with the OutputFrame is loaded so we can get to the content.
            rootPage.OutputFrameLoaded += new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            rootPage.OutputFrameLoaded -= new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        void rootPage_OutputFrameLoaded(object sender, object e)
        {
            Page outputFrame = (Page)rootPage.OutputFrame.Content;
            output = outputFrame.FindName("Output") as TextBlock;
        }

        #endregion

        async void PickImage_Click(object sender, RoutedEventArgs e)
        {
            await CopyImageToLocalFolderAsync();
        }

        async Task CopyImageToLocalFolderAsync()
        {
            FileOpenPicker picker = new Windows.Storage.Pickers.FileOpenPicker();
            picker.ViewMode = PickerViewMode.Thumbnail;
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.FileTypeFilter.Add(".jpg");
            picker.FileTypeFilter.Add(".jpeg");
            picker.FileTypeFilter.Add(".png");
            picker.CommitButtonText = "Copy";
            StorageFile file = await picker.PickSingleFileAsync();
            StorageFile newFile = await Windows.Storage.ApplicationData.Current.LocalFolder.CreateFileAsync(file.Name);
            await file.CopyAndReplaceAsync(newFile);
            this.imageRelativePath = newFile.Path.Substring(newFile.Path.LastIndexOf("\\") + 1);
            output.Text = "Image copied to application data local storage: " + newFile.Path;
        }

        void ProtocolList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            LocalFolder.Visibility = Visibility.Collapsed;
            HTTP.Visibility = Visibility.Collapsed;

            if (ProtocolList.SelectedItem == appdata)
            {
                LocalFolder.Visibility = Visibility.Visible;
            }
            else if (ProtocolList.SelectedItem == http)
            {
                HTTP.Visibility = Visibility.Visible;
            }
        }

        void SendTileNotification_Click(object sender, RoutedEventArgs e)
        {
            IWideTileNotificationContent tileContent = null;
            if (ProtocolList.SelectedItem == package) //using the ms-appx:/// protocol
            {
                ITileWideImageAndText01 wideContent = TileContentFactory.CreateTileWideImageAndText01();

                wideContent.RequireSquareContent = false;
                wideContent.TextCaptionWrap.Text = "The image is in the appx package";
                wideContent.Image.Src = "ms-appx:///images/redWide.png";
                wideContent.Image.Alt = "Red image";

                tileContent = wideContent;
            }
            else if (ProtocolList.SelectedItem == appdata) //using the appdata:///local/ protocol
            {
                ITileWideImage wideContent = TileContentFactory.CreateTileWideImage();

                wideContent.RequireSquareContent = false;
                wideContent.Image.Src = "ms-appdata:///local/" + this.imageRelativePath;
                wideContent.Image.Alt = "App data";

                tileContent = wideContent;
            }
            else if (ProtocolList.SelectedItem == http) //using http:// protocol
            {
                // Important - The Internet (Client) capability must be checked in the manifest in the Capabilities tab
                ITileWidePeekImageCollection04 wideContent = TileContentFactory.CreateTileWidePeekImageCollection04();

                wideContent.RequireSquareContent = false;
                wideContent.BaseUri = HTTPBaseURI.Text;
                wideContent.TextBodyWrap.Text = "The base URI is " + HTTPBaseURI.Text;
                wideContent.ImageMain.Src = HTTPImage1.Text;
                wideContent.ImageSmallColumn1Row1.Src = HTTPImage2.Text;
                wideContent.ImageSmallColumn1Row2.Src = HTTPImage3.Text;
                wideContent.ImageSmallColumn2Row1.Src = HTTPImage4.Text;
                wideContent.ImageSmallColumn2Row2.Src = HTTPImage5.Text;

                tileContent = wideContent;
            }

            tileContent.RequireSquareContent = false;
            TileUpdateManager.CreateTileUpdaterForApplication().Update(tileContent.CreateNotification());

            output.Text = tileContent.GetContent();
        }
    }
}
