﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using System;
using System.Linq;
using System.Collections.Generic;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using SDKTemplateCS;
using Windows.ApplicationModel.Resources.Core;
using Windows.UI.Notifications;
using NotificationsExtensions.TileContent;

namespace TilesCS
{
    public sealed partial class ScenarioInput9 : Page
    {
        MainPage rootPage = null;
        TextBlock output = null;

        public ScenarioInput9()
        {
            InitializeComponent();
        }

        #region Template-Related Code - Do not remove
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Get a pointer to our main page
            rootPage = e.Parameter as MainPage;

            // We want to be notified with the OutputFrame is loaded so we can get to the content.
            rootPage.OutputFrameLoaded += new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            rootPage.OutputFrameLoaded -= new System.EventHandler(rootPage_OutputFrameLoaded);
        }

        void rootPage_OutputFrameLoaded(object sender, object e)
        {
            Page outputFrame = (Page)rootPage.OutputFrame.Content;
            output = outputFrame.FindName("Output") as TextBlock;
        }

        #endregion

        void ViewCurrentResources_Click(object sender, RoutedEventArgs e)
        {
            string asls;
            ResourceManager.Current.DefaultContext.QualifierValues.TryGetValue("Language", out asls);

            string scale;
            ResourceManager.Current.DefaultContext.QualifierValues.TryGetValue("Scale", out scale);

            string contrast;
            ResourceManager.Current.DefaultContext.QualifierValues.TryGetValue("Contrast", out contrast);

            output.Text = "Your system is currently set to the following values: Application Language: " + asls + ", Scale: " + scale + ", Contrast: " + contrast + ". If using web images, the following query string would be appened to the URL: ?lang=" + asls + "&scale=" + scale + "&contrast=" + contrast;
        }

        void SendTileNotification_Click(object sender, RoutedEventArgs e)
        {
            string scale;
            ResourceManager.Current.DefaultContext.QualifierValues.TryGetValue("Scale", out scale);

            ITileWideSmallImageAndText03 tileContent = TileContentFactory.CreateTileWideSmallImageAndText03();
            tileContent.TextBodyWrap.Text = "graySquare.png in the xml is actually graySquare.scale-" + scale + ".png";
            tileContent.Image.Src = "ms-appx:///images/graySquare.png";
            tileContent.Image.Alt = "Gray square";

            ITileSquareImage squareTileContent = TileContentFactory.CreateTileSquareImage();
            squareTileContent.Image.Src = "ms-appx:///images/graySquare.png";
            squareTileContent.Image.Alt = "Gray square";
            tileContent.SquareContent = squareTileContent;

            TileUpdateManager.CreateTileUpdaterForApplication().Update(tileContent.CreateNotification());

            output.Text = tileContent.GetContent();
        }

        void SendTileNotificationText_Click(object sender, RoutedEventArgs e)
        {
            ITileWideText03 tileContent = TileContentFactory.CreateTileWideText03(); 
            
            // check out /en-US/resources.resw to understand where this string will come from
            tileContent.TextHeadingWrap.Text = "ms-resource:greeting";

            ITileSquareText04 squareTileContent = TileContentFactory.CreateTileSquareText04();
            squareTileContent.TextBodyWrap.Text = "ms-resource:greeting";
            tileContent.SquareContent = squareTileContent;

            TileUpdateManager.CreateTileUpdaterForApplication().Update(tileContent.CreateNotification());

            output.Text = tileContent.GetContent();
        }

    }
}
