﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using System.Diagnostics;
using System.Threading;
using Windows.ApplicationModel.Background;
using Windows.Storage;

//
// The namespace for the background tasks.
//
namespace BackgroundTask
{
    //
    // A background task always implements the IBackgroundTask interface.
    //
    public sealed class ServicingComplete : IBackgroundTask
    {
        volatile bool _CancelRequested = false;

        //
        // The Run method is the entry point of a background task.
        //
        public void Run(IBackgroundTaskInstance taskInstance)
        {
            Debug.WriteLine("ServicingComplete " + taskInstance.Task.Name + " starting...");

            //
            // Do background task activity for servicing complete.
            //
            bool Canceled = false;
            for (uint i = 0; i <= 100; i += 10)
            {
                //
                // If the cancellation handler indicated that the task was canceled, stop doing the task.
                //
                if (_CancelRequested)
                {
                    Canceled = true;
                    break;
                }

                //
                // TODO: Simulate doing work.
                //

                //
                // Indicate progress to foreground application.
                //
                taskInstance.Progress = i;
            }

            //
            // Write to LocalSettings to indicate that this background task ran.
            //
            var key = taskInstance.Task.TaskId.ToString();
            var settings = ApplicationData.Current.LocalSettings;
            if (Canceled)
            {
                settings.Values[key] = "Canceled";
            }
            else
            {
                settings.Values[key] = "Completed";
            }

            Debug.WriteLine("ServicingComplete " + taskInstance.Task.Name + (Canceled ? " Canceled" : " Completed"));
        }

        //
        // Handles background task cancellation.
        //
        private void OnCanceled(IBackgroundTaskInstance sender, BackgroundTaskCancellationReason reason)
        {
            //
            // Indicate that the background task is canceled.
            //
            _CancelRequested = true;

            Debug.WriteLine("ServicingComplete " + sender.Task.Name + " Cancel Requested...");
        }
    }
}
