﻿// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

using NotificationsExtensions.ToastContent;
using System;
using System.Text;
using Windows.Data.Xml.Dom;
using Windows.Foundation;
using Windows.UI.Core;
using Windows.UI.Notifications;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace ToastsSampleCS
{
    partial class MainPage
    {
        private ToastNotification scenario5Toast = null;
        private ToastNotification scenario6Toast = null;
        private CoreDispatcher dispatcher;
        public MainPage()
        {
            InitializeComponent();
            ScenarioList.SelectionChanged += new SelectionChangedEventHandler(ScenarioList_SelectionChanged);

            // Starting scenario is the first or based upon a previous selection
            ListBoxItem startingScenario = null;
            if (SuspensionManager.SessionState.ContainsKey("SelectedScenario"))
            {
                String selectedScenarioName = SuspensionManager.SessionState["SelectedScenario"] as string;
                startingScenario = this.FindName(selectedScenarioName) as ListBoxItem;                    
            }

            ScenarioList.SelectedItem = startingScenario != null ? startingScenario : Scenario1;
            
            Scenario1Init();
            Scenario2Init();
            Scenario3Init();
            Scenario4Init();
            Scenario5Init();
            Scenario6Init();

            Windows.UI.ViewManagement.ApplicationView.GetForCurrentView().ViewStateChanged += new TypedEventHandler<Windows.UI.ViewManagement.ApplicationView, Windows.UI.ViewManagement.ApplicationViewStateChangedEventArgs>(MainPage_ViewStateChanged);
            dispatcher = Window.Current.Dispatcher;
        }

        void MainPage_ViewStateChanged(Windows.UI.ViewManagement.ApplicationView sender, Windows.UI.ViewManagement.ApplicationViewStateChangedEventArgs args)
        {
            switch (args.ViewState)
            {
                case Windows.UI.ViewManagement.ApplicationViewState.Filled:
                    VisualStateManager.GoToState(this, "Fill", false);
                    break;
                case Windows.UI.ViewManagement.ApplicationViewState.FullScreenLandscape:
                    VisualStateManager.GoToState(this, "FullScreenLandscape", false);
                    break;
                case Windows.UI.ViewManagement.ApplicationViewState.Snapped:
                    VisualStateManager.GoToState(this, "Snapped", false);
                    break;
                case Windows.UI.ViewManagement.ApplicationViewState.FullScreenPortrait:
                    VisualStateManager.GoToState(this, "FullScreenPortrait", false);
                    break;
                default:
                    break;
            }
        }


        #region Scenario Specific Code
        void Scenario1Init()
        {
            Scenario1DisplayToastText01.Click +=
                (sender, e) => { Scenario1DisplayToast(ToastTemplateType.ToastText01); };

            Scenario1DisplayToastText02.Click +=
                (sender, e) => { Scenario1DisplayToast(ToastTemplateType.ToastText02); };

            Scenario1DisplayToastText03.Click +=
                (sender, e) => { Scenario1DisplayToast(ToastTemplateType.ToastText03); };

            Scenario1DisplayToastText04.Click +=
                (sender, e) => { Scenario1DisplayToast(ToastTemplateType.ToastText04); };
        }

        void Scenario1DisplayToast(ToastTemplateType templateType)
        {
            // Creates a toast using the notification object model, which is another project
            // in this solution.  For an example using Xml manipulation, see the function
            // DisplayToastUsingXmlManipulation below.
            IToastNotificationContent toastContent = null;

            if (templateType == ToastTemplateType.ToastText01)
            {
                IToastText01 templateContent = ToastContentFactory.CreateToastText01();
                templateContent.TextBodyWrap.Text = "Body text that wraps";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastText02)
            {
                IToastText02 templateContent = ToastContentFactory.CreateToastText02();
                templateContent.TextHeading.Text = "Heading text";
                templateContent.TextBodyWrap.Text = "Body text that wraps.";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastText03)
            {
                IToastText03 templateContent = ToastContentFactory.CreateToastText03();
                templateContent.TextHeadingWrap.Text = "Heading text that wraps";
                templateContent.TextBody.Text = "Body text";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastText04)
            {
                IToastText04 templateContent = ToastContentFactory.CreateToastText04();
                templateContent.TextHeading.Text = "Heading text";
                templateContent.TextBody1.Text = "Body text";
                templateContent.TextBody2.Text = "Another body text";
                toastContent = templateContent;
            }

            Scenario1OutputText.Text = toastContent.GetContent();

            // Create a toast, then create a ToastNotifier object to show
            // the toast
            ToastNotification toast = toastContent.CreateNotification();

            // If you have other applications in your package, you can specify the AppId of
            // the app to create a ToastNotifier for that application
            ToastNotificationManager.CreateToastNotifier().Show(toast);
        }

        void DisplayToastUsingXmlManipulation(ToastTemplateType templateType)
        {
            // GetTemplateContent returns a Windows.Data.Xml.Dom.XmlDocument object containing
            // the toast XML
            XmlDocument toastXml = ToastNotificationManager.GetTemplateContent(templateType);

            // You can use the methods from the XML document to specify all of the
            // required parameters for the toast
            XmlNodeList stringElements = toastXml.GetElementsByTagName("text");
            for (uint i = 0; i < stringElements.Length; i++)
            {
                // In order to see which text inputs will wrap across lines, a very long string for each text
                // input will be created using this loop
                StringBuilder text = new StringBuilder(150);
                uint inputNumber = i + 1;
                for (int j = 0; j < 10; j++)
                {
                    text.Append("Text input " + inputNumber + " ");
                }
                stringElements.Item(i).AppendChild(toastXml.CreateTextNode(text.ToString()));
            }

            // Create a toast from the Xml, then create a ToastNotifier object to show
            // the toast
            ToastNotification toast = new ToastNotification(toastXml);

            // If you have other applications in your package, you can specify the AppId of
            // the app to create a ToastNotifier for that application
            ToastNotificationManager.CreateToastNotifier().Show(toast);
        }

        void Scenario2Init()
        {
            Scenario2DisplayToastImage01.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText01, "images/toastImageAndText.png", Scenario2OutputText); };

            Scenario2DisplayToastImage02.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText02, "images/toastImageAndText.png", Scenario2OutputText); };

            Scenario2DisplayToastImage03.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText03, "images/toastImageAndText.png", Scenario2OutputText); };

            Scenario2DisplayToastImage04.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText04, "images/toastImageAndText.png", Scenario2OutputText); };
        }

        void DisplayToastWithImage(ToastTemplateType templateType, string toastImageSrc, TextBlock output)
        {
            IToastNotificationContent toastContent = null;

            if (templateType == ToastTemplateType.ToastImageAndText01)
            {
                IToastImageAndText01 templateContent = ToastContentFactory.CreateToastImageAndText01();
                templateContent.TextBodyWrap.Text = "Body text that wraps";
                templateContent.Image.Src = toastImageSrc;
                templateContent.Image.Alt = "Placeholder image";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastImageAndText02)
            {
                IToastImageAndText02 templateContent = ToastContentFactory.CreateToastImageAndText02();
                templateContent.TextHeading.Text = "Heading text";
                templateContent.TextBodyWrap.Text = "Body text that wraps.";
                templateContent.Image.Src = toastImageSrc;
                templateContent.Image.Alt = "Placeholder image";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastImageAndText03)
            {
                IToastImageAndText03 templateContent = ToastContentFactory.CreateToastImageAndText03();
                templateContent.TextHeadingWrap.Text = "Heading text that wraps";
                templateContent.TextBody.Text = "Body text";
                templateContent.Image.Src = toastImageSrc;
                templateContent.Image.Alt = "Placeholder image";
                toastContent = templateContent;
            }
            else if (templateType == ToastTemplateType.ToastImageAndText04)
            {
                IToastImageAndText04 templateContent = ToastContentFactory.CreateToastImageAndText04();
                templateContent.TextHeading.Text = "Heading text";
                templateContent.TextBody1.Text = "Body text";
                templateContent.TextBody2.Text = "Another body text";
                templateContent.Image.Src = toastImageSrc;
                templateContent.Image.Alt = "Placeholder image";
                toastContent = templateContent;
            }

            output.Text = toastContent.GetContent();

            // Create a toast from the Xml, then create a ToastNotifier object to show
            // the toast
            ToastNotification toast = toastContent.CreateNotification();

            // If you have other applications in your package, you can specify the AppId of
            // the app to create a ToastNotifier for that application
            ToastNotificationManager.CreateToastNotifier().Show(toast);
        }
        
        void Scenario3Init()
        {
            Scenario3DisplayToastImage01.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText01, Scenario3ImageUrl.Text, Scenario3OutputText); };

            Scenario3DisplayToastImage02.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText02, Scenario3ImageUrl.Text, Scenario3OutputText); };

            Scenario3DisplayToastImage03.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText03, Scenario3ImageUrl.Text, Scenario3OutputText); };

            Scenario3DisplayToastImage04.Click +=
                (sender, e) => { DisplayToastWithImage(ToastTemplateType.ToastImageAndText04, Scenario3ImageUrl.Text, Scenario3OutputText); };
        }

        void Scenario4Init()
        {
            Scenario4DisplayToastSilent.Click += (sender, e) => { Scenario4DisplayToastWithSound("Silent"); };
            Scenario4DisplayToastDefault.Click += (sender, e) => { Scenario4DisplayToastWithSound("Default"); };
            Scenario4DisplayToastMail.Click += (sender, e) => { Scenario4DisplayToastWithSound("Mail"); };
            Scenario4DisplayToastSMS.Click += (sender, e) => { Scenario4DisplayToastWithSound("SMS"); };
            Scenario4DisplayToastIM.Click += (sender, e) => { Scenario4DisplayToastWithSound("IM"); };
            Scenario4DisplayToastReminder.Click += (sender, e) => { Scenario4DisplayToastWithSound("Reminder"); };
        }

        void Scenario4DisplayToastWithSound(string audioSrc)
        {
            IToastText02 toastContent = ToastContentFactory.CreateToastText02();
            toastContent.TextHeading.Text = "Sound:";
            toastContent.TextBodyWrap.Text = audioSrc;
            toastContent.Audio.Content = (ToastAudioContent)Enum.Parse(typeof(ToastAudioContent), audioSrc);

            Scenario4OutputText.Text = toastContent.GetContent();

            // Create a toast, then create a ToastNotifier object to show
            // the toast
            ToastNotification toast = toastContent.CreateNotification();

            // If you have other applications in your package, you can specify the AppId of
            // the app to create a ToastNotifier for that application
            ToastNotificationManager.CreateToastNotifier().Show(toast);
        }

        void Scenario5Init()
        {
            Scenario5DisplayToastWithCallbacks.Click += Scenario5DisplayToastWithCallbacks_Click;
            Scenario5HideToast.Click += Scenario5HideToast_Click;
        }

        void Scenario5DisplayToastWithCallbacks_Click(object sender, RoutedEventArgs e)
        {
            IToastText02 toastContent = ToastContentFactory.CreateToastText02();

            // Set the launch activation context parameter on the toast.
            // The context can be recovered through the app Activation event
            toastContent.Launch = "Context123";

            toastContent.TextHeading.Text = "Tap toast";
            toastContent.TextBodyWrap.Text = "Or swipe to dismiss";

            // You can listen for the "Activated" event provided on the toast object
            // or listen to the "OnLaunched" event off the Windows.UI.Xaml.Application
            // object to tell when the user clicks the toast.
            //
            // The difference is that the OnLaunched event will
            // be raised by local, scheduled and cloud toasts, while the event provided by the 
            // toast object will only be raised by local toasts. 
            //
            // In this example, we'll use the event off the CoreApplication object.
            scenario5Toast = toastContent.CreateNotification();
            scenario5Toast.Dismissed += toast_Dismissed;
            scenario5Toast.Failed += toast_Failed;

            ToastNotificationManager.CreateToastNotifier().Show(scenario5Toast);
        }

        void Scenario5HideToast_Click(object sender, RoutedEventArgs e)
        {
            if (scenario5Toast != null)
            {
                ToastNotificationManager.CreateToastNotifier().Hide(scenario5Toast);
                scenario5Toast = null;
            }
            else
            {
                Scenario5OutputText.Text = "No toast has been displayed from Scenario 5";
            }
        }

        void toast_Failed(ToastNotification sender, ToastFailedEventArgs e)
        {
            String outputText = "The toast encountered an error";

            dispatcher.InvokeAsync(CoreDispatcherPriority.Normal, (object obj, InvokedHandlerArgs args) =>
            {
                Scenario5OutputText.Text = outputText;
            }, outputText, null);
        }

        void toast_Dismissed(ToastNotification sender, ToastDismissedEventArgs e)
        {
            String outputText = "";

            switch (e.Reason)
            {
                case ToastDismissalReason.ApplicationHidden:
                    outputText = "The app hid the toast using ToastNotifier.Hide(toast)";
                    break;
                case ToastDismissalReason.UserCanceled:
                    outputText = "The user dismissed this toast";
                    break;
                case ToastDismissalReason.TimedOut:
                    outputText = "The toast has timed out";
                    break;
            }

            dispatcher.InvokeAsync(CoreDispatcherPriority.Normal, (object obj, InvokedHandlerArgs args) =>
            {
                Scenario5OutputText.Text = outputText;
            }, outputText, null);
        }

        public void LaunchedFromToast(String arguments)
        {
            // This function is called from the OnLaunched function in App.xaml.cs.  Refer there to see how to handle activation.
            ScenarioList.SelectedItem = Scenario5;
            Scenario5OutputText.Text = "A toast was clicked on with activation arguments: " + arguments;
        }

        void Scenario6Init()
        {
            Scenario6Looping.Click += (sender, e) => { Scenario6DisplayLongToast(true); };
            Scenario6NoLooping.Click += (sender, e) => { Scenario6DisplayLongToast(false); };
            Scenario6HideToast.Click += Scenario6HideToast_Click;
        }

        void Scenario6DisplayLongToast(bool loopAudio)
        {
            IToastText02 toastContent = ToastContentFactory.CreateToastText02();

            // Toasts can optionally be set to long duration
            toastContent.Duration = ToastDuration.Long;

            toastContent.TextHeading.Text = "Long Duration Toast";

            if (loopAudio)
            {
                toastContent.Audio.Loop = true;
                toastContent.Audio.Content = ToastAudioContent.LoopingAlarm;
                toastContent.TextBodyWrap.Text = "Looping audio";
            }
            else
            {
                toastContent.Audio.Content = ToastAudioContent.IM;
            }

            scenario6Toast = toastContent.CreateNotification();
            ToastNotificationManager.CreateToastNotifier().Show(scenario6Toast);

            Scenario6OutputText.Text = toastContent.GetContent();
        }

        void Scenario6HideToast_Click(object sender, RoutedEventArgs e)
        {
            if (scenario6Toast != null)
            {
                ToastNotificationManager.CreateToastNotifier().Hide(scenario6Toast);
                scenario6Toast = null;
            }
            else
            {
                Scenario6OutputText.Text = "No toast has been displayed from Scenario 6";
            }
        }


        #endregion

        void ScenarioList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ResetAll();
            if (ScenarioList.SelectedItem == Scenario1)
            {
                Scenario1Input.Visibility = Visibility.Visible;
                Scenario1Output.Visibility = Visibility.Visible;
            }
            else if (ScenarioList.SelectedItem == Scenario2)
            {
                Scenario2Input.Visibility = Visibility.Visible;
                Scenario2Output.Visibility = Visibility.Visible;
            }
            else if (ScenarioList.SelectedItem == Scenario3)
            {
                Scenario3Input.Visibility = Visibility.Visible;
                Scenario3Output.Visibility = Visibility.Visible;
            }
            else if (ScenarioList.SelectedItem == Scenario4)
            {
                Scenario4Input.Visibility = Visibility.Visible;
                Scenario4Output.Visibility = Visibility.Visible;
            }
            else if (ScenarioList.SelectedItem == Scenario5)
            {
                Scenario5Input.Visibility = Visibility.Visible;
                Scenario5Output.Visibility = Visibility.Visible;
            }
            else if (ScenarioList.SelectedItem == Scenario6)
            {
                Scenario6Input.Visibility = Visibility.Visible;
                Scenario6Output.Visibility = Visibility.Visible;
            }

            if (ScenarioList.SelectedItem != null)
            {
                ListBoxItem selectedListBoxItem = ScenarioList.SelectedItem as ListBoxItem;
                SuspensionManager.SessionState["SelectedScenario"] = selectedListBoxItem.Name;
            }
        }

        public void ResetAll()
        {
            Scenario1Input.Visibility = Visibility.Collapsed;
            Scenario1Output.Visibility = Visibility.Collapsed;
            Scenario2Input.Visibility = Visibility.Collapsed;
            Scenario2Output.Visibility = Visibility.Collapsed;
            Scenario3Input.Visibility = Visibility.Collapsed;
            Scenario3Output.Visibility = Visibility.Collapsed;
            Scenario4Input.Visibility = Visibility.Collapsed;
            Scenario4Output.Visibility = Visibility.Collapsed;
            Scenario5Input.Visibility = Visibility.Collapsed;
            Scenario5Output.Visibility = Visibility.Collapsed;
            Scenario6Input.Visibility = Visibility.Collapsed;
            Scenario6Output.Visibility = Visibility.Collapsed;
        }

        async void Footer_Click(object sender, RoutedEventArgs e)
        {
            await Windows.System.Launcher.LaunchUriAsync(new Uri(((HyperlinkButton)sender).Tag.ToString()));
        }

    }
}
